==> haskell-doclayout-0.4.0.1-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doclayout
version:              0.4.0.1
visibility:           public
id:                   doclayout-0.4.0.1-8HYTa6Z9ApODZ8xpShWULy
key:                  doclayout-0.4.0.1-8HYTa6Z9ApODZ8xpShWULy
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  5fc7a5667699b1397372f3146fc6646c
exposed:              True
exposed-modules:      Text.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doclayout-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doclayout-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doclayout-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.4.0.1-8HYTa6Z9ApODZ8xpShWULy
depends:
    base-4.17.2.1 containers-0.6.7
    emojis-0.1.4.1-4tXPs3L82IMDXThre4dKn2 mtl-2.2.2
    safe-0.3.21-JSgKJ1qQ11UGSifs2bSHTA text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doclayout-0.4.0.1-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doclayout
version:              0.4.0.1
visibility:           public
id:                   doclayout-0.4.0.1-9E6SUVIGrA72EmthT6YScZ
key:                  doclayout-0.4.0.1-9E6SUVIGrA72EmthT6YScZ
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doclayout
synopsis:             A prettyprinting library for laying out text documents.
description:
    doclayout is a prettyprinting library for laying out
    text documents, with several features not present
    in prettyprinting libraries designed for code.  It
    was designed for use in pandoc.

category:             Text
abi:                  31b77b29528e6bb4e07883046253f830
exposed:              True
exposed-modules:      Text.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/doclayout-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doclayout-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doclayout-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doclayout
hs-libraries:         HSdoclayout-0.4.0.1-9E6SUVIGrA72EmthT6YScZ
depends:
    base-4.17.2.1 containers-0.6.7
    emojis-0.1.4.1-Lci0sIqjuZ2LxBbQvFIUVy mtl-2.2.2
    safe-0.3.21-IyrA7K5ohwh1bwsZPWGLKL text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-doclayout/html/doclayout.haddock
haddock-html:         /usr/share/doc/haskell-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
